package com.sanspro.salaryCalculator;

import java.text.DecimalFormat;

import com.google.ads.AdRequest;
import com.google.ads.AdSize;
import com.google.ads.AdView;

import android.app.Activity;
import android.content.Context;
import android.graphics.Color;
import android.os.Bundle;
import android.os.IBinder;
import android.text.method.ScrollingMovementMethod;
import android.view.Gravity;
import android.view.View;
import android.view.View.OnClickListener;
import android.view.inputmethod.InputMethodManager;
import android.widget.Button;
import android.widget.EditText;
import android.widget.LinearLayout;
import android.widget.TextView;

/**
 * Class to generate salary details for Current CTC and ECTC based on the Hike
 * percentage and TDS percentage.
 * 
 * @author Santhosh Kumar DK
 * 
 */
public class CalculatorHome extends Activity implements OnClickListener {

	static DecimalFormat formatter = new DecimalFormat("#,###.00");
	private final String ADMOB_PUBLISHER_ID = "a1522c8c7879284";
	private AdView adView;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);

		setContentView(R.layout.activity_calculator_home);

		Button btn = (Button) findViewById(R.id.calculate_button);
		btn.setOnClickListener(this);

		/**
		 * AdMob Ads - START
		 */
		// Create the adView
		adView = new AdView(this, AdSize.BANNER, ADMOB_PUBLISHER_ID);
		LinearLayout layout = (LinearLayout) findViewById(R.id.adMobId);
		layout.addView(adView);
		adView.loadAd(new AdRequest());
		/**
		 * AdMob Ads - END
		 */

	}

	@Override
	public void onClick(View v) {
		if (v.getId() == R.id.calculate_button) {
			EditText CTC = (EditText) findViewById(R.id.ctcText);
			EditText ECTCPercent = (EditText) findViewById(R.id.expHikePercentageText);
			EditText TDSPercent = (EditText) findViewById(R.id.tdsText);
			calculateSalaries(CTC, ECTCPercent, TDSPercent);
		}
	}

	public void calculateSalaries(EditText cTC, EditText eCTCPercent,
			EditText tDSPercent) {

		double CTC = 0;
		int ECTCPercent = 0;
		int TDSPercent = 10; // 10 TDS percent by default
		StringBuilder sb = new StringBuilder();
		TextView resultText = (TextView) findViewById(R.id.resultText);
		try {
			CTC = Double.valueOf(cTC.getText().toString());
			ECTCPercent = Integer.parseInt(eCTCPercent.getText().toString());
			TDSPercent = Integer.parseInt(tDSPercent.getText().toString());
		} catch (Exception e) {
			sb.append("Please enter valid values!");
			resultText.setTextColor(Color.RED);
			resultText.setGravity(Gravity.CENTER);
			InputMethodManager imm = (InputMethodManager) getSystemService(Context.INPUT_METHOD_SERVICE);
			imm.hideSoftInputFromWindow(
					(IBinder) findViewById(R.id.activity_calculator_home)
							.getWindowToken(), 0);
			resultText.setText(sb.toString());
			return;
		}
		sb.append("Current ").append("\n");
		sb.append("-----------------------------").append("\n");
		sb.append("CTC : " + CTC).append("\n");
		calculateSalary(CTC, TDSPercent, sb);
		sb.append("-----------------------------");
		// Calculate hike
		calculateHikeSalary(CTC, ECTCPercent, TDSPercent, sb);
		resultText.setTextColor(Color.BLACK);
		resultText.setGravity(Gravity.LEFT);
		resultText.setMovementMethod(new ScrollingMovementMethod());
		InputMethodManager imm = (InputMethodManager) getSystemService(Context.INPUT_METHOD_SERVICE);
		imm.hideSoftInputFromWindow(
				(IBinder) findViewById(R.id.activity_calculator_home)
						.getWindowToken(), 0);
		resultText.setText(sb.toString());
	}

	private void calculateHikeSalary(double ctc, int ECTCPercent,
			int tdsPercent, StringBuilder sb) {
		float perc = (ECTCPercent / 100.0f);
		double hikeamount = (ctc * perc);

		double ectc = ctc + hikeamount;
		sb.append("\n\n");
		sb.append("Expected ").append("\n");
		sb.append("-----------------------------").append("\n");
		sb.append("Percentage : " + ECTCPercent + "%").append(" ~ " + perc)
				.append("\n");
		sb.append("Hike Amount : " + Math.ceil(hikeamount))
				.append(" ~ " + String.format("%.2f", hikeamount / 100000))
				.append(" Lakhs").append("\n");
		sb.append("CTC : " + Math.ceil(ectc))
				.append(" ~ " + String.format("%.2f", (ectc / 100000)))
				.append(" Lakhs").append("\n");
		sb.append("GROSS : " + String.format("%.2f", ((ectc / 12))))
				.append(" ~ " + String.format("%.2f", (ectc / 12) / 100000))
				.append(" Lakhs").append("\n");
		calculateSalary(ectc, tdsPercent, sb);
		sb.append("\n\n");
	}

	private void calculateSalary(double ctc, int tdsPercent, StringBuilder sb) {
		double gross = ctc / 12;
		float tdsPerc = (tdsPercent / 100.0f);
		double net = (double) (gross - (gross * tdsPerc));
		sb.append(
				"TDS : "
						+ String.format("%.2f",
								(((double) (((ctc / 12) * tdsPerc)))))).append(
				"\n");
		sb.append(
				"Monthly salary : " + formatter.format(Math.ceil(net)) + " /-")
				.append("\n");
	}

	@Override
	public void onDestroy() {
		if (adView != null) {
			adView.destroy();
		}
		super.onDestroy();
	}

}
